@@ -5,8 +5,7 @@ knitr::opts_chunk$set(fig.width = 7.2, fig.asp = 0.7)
 library("TreeSearch")
 
 ## ----Load-data----------------------------------------------------------------
-rawData <- TreeSearch::inapplicable.datasets[['Vinther2008']]
-vinther <- phangorn::phyDat(rawData, type = 'USER', levels = c(0:9, '-'))
+vinther <- TreeSearch::inapplicable.phyData[["Vinther2008"]]
 
 ## ----RNG-version--------------------------------------------------------------
 # Set a random seed so that random functions in this document are reproducible
@@ -17,7 +16,7 @@ set.seed(0)
 bestTrees <- MaximizeParsimony(vinther)
 
 ## ----inspect-progress---------------------------------------------------------
-firstHit <- attr(bestTrees, 'firstHit')
+firstHit <- attr(bestTrees, "firstHit")
 firstHit
 
 ## ----map-search, fig.asp = 1--------------------------------------------------
@@ -29,10 +28,10 @@ par(mar = rep(0, 4))
 TreeDist::Plot3(map,
                 col = cols[rep(seq_along(firstHit), firstHit)],
                 pch = 16, cex = 2,
-                axes = FALSE, xlab = '', ylab = '', asp = 1)
+                axes = FALSE, xlab = "", ylab = "", asp = 1)
 TreeTools::MSTEdges(distances, plot = TRUE, map[, 1], map[, 2],
-                    col = '#00000030', lty = 2)
-legend('topright', names(firstHit), col = cols, pch = 16, bty = 'n')
+                    col = "#00000030", lty = 2)
+legend("topright", names(firstHit), col = cols, pch = 16, bty = "n")
 
 ## ----second-pass, message = FALSE---------------------------------------------
 bestTrees <- MaximizeParsimony(vinther, tree = bestTrees,
@@ -51,15 +50,15 @@ par(mar = rep(0.25, 4), cex = 0.75) # make plot easier to read
 majCons <- ape::consensus(bestTrees, p = 0.5)
 splitFreqs <- TreeTools::SplitFrequency(majCons, bestTrees) / length(bestTrees)
 plot(majCons)
-TreeTools::LabelSplits(majCons, round(splitFreqs * 100), unit = '%',
+TreeTools::LabelSplits(majCons, round(splitFreqs * 100), unit = "%",
                        col = TreeTools::SupportColor(splitFreqs),
-                       frame = 'none', pos = 3L)
+                       frame = "none", pos = 3L)
 
 ## ----Jackknife-annotations----------------------------------------------------
 nReplicates <- 10
 jackTrees <- lapply(logical(nReplicates), function (x)
   Resample(vinther, bestTrees, ratchIter = 0, tbrIter = 1, maxHits = 4,
-          verbosity = 0)
+           verbosity = 0)
 )
 
 strict <- ape::consensus(bestTrees, p = 1)
@@ -79,7 +78,7 @@ par(mar = rep(0, 4), cex = 0.8)
 plot(strict)
 TreeTools::LabelSplits(strict, signif(concordance, 3),
                        col = TreeTools::SupportColor(concordance / max(concordance)),
-                       frame = 'none', pos = 3L)
+                       frame = "none", pos = 3L)
 
 ## ----stability----------------------------------------------------------------
 par(mar = rep(0, 4), cex = 0.8)
@@ -91,12 +90,12 @@ Rogue::QuickRogue(bestTrees, p = 1)
 
 ## ----cons-without-halk--------------------------------------------------------
 par(mar = rep(0, 4), cex = 0.8)
-noWiwaxia <- lapply(bestTrees, TreeTools::DropTip, 'Wiwaxia')
+noWiwaxia <- lapply(bestTrees, TreeTools::DropTip, "Wiwaxia")
 plot(ape::consensus(noWiwaxia), tip.color = Rogue::ColByStability(noWiwaxia))
 
 ## ----restore-wiwaxia----------------------------------------------------------
 par(mar = rep(0, 4), cex = 0.8)
-xx <- TreeTools::RoguePlot(bestTrees, 'Wiwaxia', p = 1)
+xx <- TreeTools::RoguePlot(bestTrees, "Wiwaxia", p = 1)
 
 ## ----iw-search, message = FALSE-----------------------------------------------
 iwTrees <- MaximizeParsimony(vinther, concavity = 10)
@@ -104,7 +103,7 @@ par(mar = rep(0.25, 4), cex = 0.75) # make plot easier to read
 plot(ape::consensus(iwTrees))
 
 ## ----simple-constraints, fig.width = 4, fig.align = "center", message = FALSE----
-library("TreeTools", quietly = TRUE, warn.conflicts = FALSE)
+library("TreeTools", quietly = TRUE)
 constraint <- MatrixToPhyDat(c(a = 1, b = 1, c = 0, d = 0, e = 0, f = 0))
 characters <- MatrixToPhyDat(matrix(
   c(0, 1, 1, 1, 0, 0,
@@ -119,7 +118,7 @@ characters <- MatrixToPhyDat(matrix(
     1, 1, 1, 1, 0, 0, 0), ncol = 2,
   dimnames = list(letters[1:7], NULL)))
 constraint <- MatrixToPhyDat(matrix(
-  c(0, 0, 1, '?', 1, 1,
+  c(0, 0, 1, "?", 1, 1,
     1, 1, 1,   1, 0, 0), ncol = 2,
   dimnames = list(letters[1:6], NULL)))
 plot(MaximizeParsimony(characters, constraint = constraint,
